function varargout = ps_LST_doit(job,arg)

%     ps_LST_doit.m - Determination of optimal initial threshold, 
%     part of the LST toolbox
%     Copyright (C) 2013  Paul Schmidt
% 
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

res = zeros(0, 4);

fprintf('Compare segmentations...\n')

for ii = 1:numel(job.data_plm)

    [job_pth, job_name, job_ext] = spm_fileparts(job.data_plm{ii});
    
    kk = 0;
    % which reference segmentation is the right one?
    for jj = 1:numel(job.data_ref)
        [ref_pth, ref_name] = fileparts(job.data_ref{jj});
        if numel(ref_pth) == numel(job_pth)
            if ref_pth == job_pth;
                kk = jj;
            end
        end
    end
    
    if kk == 0
       error(['No reference image found in ', job_pth])
    end

    pos_underline = strfind(job_name, '_');
    kappa_tmp = str2num(job_name((pos_underline(2)+1):(pos_underline(3)-1)))/100;
    
    % read lesion probability map and apply binary threshold
    plm = spm_read_vols(spm_vol(fullfile(job_pth, [job_name, job_ext])));
    blm = 1 .* (plm >= job.bin_thresh);
    clear plm;
    
    % read reference segmentation
    ref = spm_read_vols(spm_vol(job.data_ref{kk}));
    
    % load indx of brain voxels
    load(fullfile(ref_pth, 'indx.mat'))
    
    % calculate ...
    % ... FP ...
    FP = sum(ref(indx_total) == 0 & blm(indx_total) > 0);
    % ... TP ...
    TP = sum(ref(indx_total) > 0 & blm(indx_total) > 0);
    % ... FN ...
    FN = sum(ref(indx_total) > 0 & blm(indx_total) == 0);
    % ... TN ...
    TN = sum(ref(indx_total) == 0 & blm(indx_total) == 0);
    % ... sensitivity ...
    SE = TP / (TP + FN);
    % ... specificity ...
    SP = TN / (TN + FP);
    % ... Dice coefficient
    DC = 2 * TP / (2 * TP + FP + FN);
    
    res(end+1,:) = [kappa_tmp; DC; SE; SP];

end

figure
u = -0.01 + (0.01+0.01) .* rand(size(res, 1), 1);
scatter(res(:,1) + u, res(:,2), 'k', 'filled')
xlabel('kappa')
ylabel('Dice Coefficient')

% write results to current folder
csvwrite(fullfile(pwd, 'kappa_dice_se_sp.csv'), res)
fprintf('Results are written to the file\n')
fprintf(fullfile(pwd, 'kappa_dice_se_sp.csv'), '\n')
fprintf('\n')

c = clock();
disp(['Finished successfully on ', datestr(c)]);
varargout{:} = ['Finished successfully on ', datestr(c)];

return

