function varargout = ps_LST_lesvolume(job,arg)

%     ps_LST_thresholding.m - Compute binary lesion maps, 
%     part of the LST toolbox
%     Copyright (C) 2012  Paul Schmidt
% 
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

fprintf('Compute total lesion volume for...\n')
nimgs = numel(job.data_plm_thresh);
dat = zeros(nimgs, 1);

for ii = 1:nimgs
    fprintf(job.data_plm_thresh{ii}, '\n');
    [job_pth, job_plm, job_ext] = fileparts(job.data_plm_thresh{ii});
    
    VLes = spm_vol(fullfile(job_pth, [job_plm, job_ext]));
    Les = spm_read_vols(VLes);
    volfactor = abs(det(VLes.mat(1:3,1:3))) /  1000;
    vol_txt = fullfile(job_pth,['tlv_', job_plm, '.txt']);
    fid = fopen(vol_txt, 'w');
    vol = volfactor*sum(sum(sum(Les > 0)));
    fprintf(fid,'%5.3f\t',vol);
    fclose(fid);
    fprintf('\n');
    dat(ii) = vol;
end

% save all data to one file
if job.adiof
    [job_pth, job_plm] = fileparts(job.data_plm_thresh{1});
    fid = fopen(fullfile(job_pth, 'tlv_all.csv'), 'w');
    for ii = 1:nimgs
        [job_pth, job_plm] = fileparts(job.data_plm_thresh{ii});
        fprintf(fid, [job_plm, ', %5.3f\n'], dat(ii));
    end
    fclose(fid);
end

c = clock();
disp(['Finished successfully on ', datestr(c)]);
varargout{:} = ['Finished successfully on ', datestr(c)];

return

